@@ -90,36 +90,35 @@ def set_cross_references(client: weaviate.client, model: dict, datapoints: list,
     pointcount = batchcount = 0
     batch = weaviate.ReferenceBatchRequest()
 
-    for point in datapoints:
+    if len(datapoints) > 0:
+        for point in datapoints:
 
-        pointcount += 1
-        produuid = generate_uuid_for_datapoint(model, point)
+            pointcount += 1
+            produuid = generate_uuid_for_datapoint(model, point)
 
-        for key in point:
-            if key != 'classname' and point[key] is not None and point[key] != '':
-                entity = get_reference_class_name_from_field(key)
-                if entity in entities:
+            for key in point:
+                if key != 'classname' and point[key] is not None and point[key] != '':
+                    entity = get_reference_class_name_from_field(key)
+                    if entity in entities:
 
-                    entuuid = generate_uuid_for_entity(entity, point[key])
-                    batch.add(produuid, point['classname'], "of" + entity, entuuid)
+                        entuuid = generate_uuid_for_entity(entity, point[key])
+                        batch.add(produuid, point['classname'], "of" + entity, entuuid)
 
-                    batchcount += 1
-                    if batchcount >= maxbatch:
-                        result = client.batch.create_references(batch)
-                        check_batch_result(result)
+                        batchcount += 1
+                        if batchcount >= maxbatch:
+                            result = client.batch.create_references(batch)
+                            check_batch_result(result)
 
-                        batch = weaviate.ReferenceBatchRequest()
-                        batchcount = 0
-                        if verbose:
-                            print("Cross reference data points -----------:", pointcount, end="\r")
+                            batch = weaviate.ReferenceBatchRequest()
+                            batchcount = 0
+                            if verbose:
+                                print("Cross reference data points -----------:", pointcount, end="\r")
 
-    if batchcount > 0:
-        result = client.batch.create_references(batch)
-        check_batch_result(result)
-        if verbose:
-            print("Cross reference data points -----------:", pointcount)
-    elif verbose:
-        print("")
+        if batchcount > 0:
+            result = client.batch.create_references(batch)
+            check_batch_result(result)
+            if verbose:
+                print("Cross reference data points -----------:", pointcount)
 
 
 def import_entities(client: weaviate.client, entities: list, maxbatch: int, verbose: bool):
@@ -196,35 +195,34 @@ def import_datapoints(client: weaviate.client, model: dict, datapoints: list, ma
     totalcount = batchcount = 0
     batch = weaviate.ObjectsBatchRequest()
 
-    for point in datapoints:
+    if len(datapoints) > 0:
+        for point in datapoints:
 
-        thing = {}
-        for key in point:
-            if key != 'classname':
-                thing[key] = point[key]
+            thing = {}
+            for key in point:
+                if key != 'classname':
+                    thing[key] = point[key]
 
-        newuuid = generate_uuid_for_datapoint(model, point)
+            newuuid = generate_uuid_for_datapoint(model, point)
 
-        batch.add(thing, point['classname'], newuuid)
-        batchcount += 1
-        totalcount += 1
+            batch.add(thing, point['classname'], newuuid)
+            batchcount += 1
+            totalcount += 1
 
-        if batchcount >= maxbatch:
+            if batchcount >= maxbatch:
+                result = client.batch.create_objects(batch)
+                check_batch_result(result)
+                batch = weaviate.ObjectsBatchRequest()
+                batchcount = 0
+                if verbose:
+                    print("Data points imported into Weaviate ----:", totalcount, end="\r")
+
+        # if there are left over points in the last batch, import these last data points
+        if batchcount > 0:
             result = client.batch.create_objects(batch)
             check_batch_result(result)
-            batch = weaviate.ObjectsBatchRequest()
-            batchcount = 0
             if verbose:
-                print("Data points imported into Weaviate ----:", totalcount, end="\r")
-
-    # if there are left over points in the last batch, import these last data points
-    if batchcount > 0:
-        result = client.batch.create_objects(batch)
-        check_batch_result(result)
-        if verbose:
-            print("Data points imported into Weaviate ----:", totalcount)
-    elif verbose:
-        print("")
+                print("Data points imported into Weaviate ----:", totalcount)
 
 
 def import_datapoints_nonbatch(client: weaviate.client, model: dict, datapoints: list, maxbatch: int, verbose: bool):
